@@ -38,6 +38,7 @@
  ****************************************************************************/
 
 #include <nuttx/config.h>
+#include <inttypes.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <unistd.h>
@@ -66,7 +67,7 @@ int main(int argc, FAR char *argv[])
           break;
         }
 
-      printf("Pressure value = %05d\n", sample);
+      printf("Pressure value = %05" PRId32 "\n", sample);
 
       usleep(500000);
     }
