@@ -37,6 +37,7 @@
  * Included Files
  ****************************************************************************/
 
+#include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -219,7 +220,7 @@ static void draw_rect24(FAR void *fbmem, FAR struct fb_overlayinfo_s * oinfo,
   g = (rgb >> 8);
   b = (rgb >> 16);
 
-  printf("Fill area (%d,%d,%d,%d) with color: %08x -> (r,g,b) = "
+  printf("Fill area (%d,%d,%d,%d) with color: %08" PRIx32 " -> (r,g,b) = "
          "(%02x,%02x,%02x)\n", area->x, area->y, area->w, area->h,
          rgb, b, g, r);
 
@@ -260,8 +261,9 @@ static void draw_rect32(FAR void *fbmem, FAR struct fb_overlayinfo_s * oinfo,
   FAR uint32_t *dest;
   FAR uint8_t  *row;
 
-  printf("Fill area (%d,%d,%d,%d) with color: %08x -> (a,r,g,b) = "
-         "(%02x,%02x,%02x,%02x)\n", area->x, area->y, area->w, area->h,
+  printf("Fill area (%d,%d,%d,%d) with color: %08" PRIx32 " -> (a,r,g,b) = "
+         "(%02" PRIx32 ",%02" PRIx32 ",%02" PRIx32 ",%02" PRIx32 ")\n",
+         area->x, area->y, area->w, area->h,
          argb, argb >> 24, argb >> 16, argb >> 8, argb);
 
   row = (FAR uint8_t *)fbmem + oinfo->stride * area->y;
@@ -292,30 +294,30 @@ static void draw_rect32(FAR void *fbmem, FAR struct fb_overlayinfo_s * oinfo,
 #ifdef CONFIG_FB_CMAP
 static int video_putcmap(int fb, FAR const struct fb_cmap_s *cmap)
 {
-    int n;
-    int ret;
+  int n;
+  int ret;
 
-    printf("Set cmap\n");
-    for (n = cmap->first; n < cmap->len; n++)
-      {
-          printf("  Color %d: (a,r,g,b) = (%02x,%02x,%02x,%02x)\n", n,
+  printf("Set cmap\n");
+  for (n = cmap->first; n < cmap->len; n++)
+    {
+      printf("  Color %d: (a,r,g,b) = (%02x,%02x,%02x,%02x)\n", n,
 #  ifdef CONFIG_CMAP_TRANSPARENCY
-                 cmap->transp[n],
+             cmap->transp[n],
 #  else
-                 (uint8_t)0xff,
+             (uint8_t)0xff,
 #  endif
-                 cmap->red[n],
-                 cmap->green[n],
-                 cmap->blue[n]);
-      }
+             cmap->red[n],
+             cmap->green[n],
+             cmap->blue[n]);
+    }
 
-    ret = ioctl(fb, FBIOPUT_CMAP, (unsigned long)(uintptr_t)cmap);
-    if (ret != OK)
-      {
-          fprintf(stderr, "Unable to set camp\n");
-      }
+  ret = ioctl(fb, FBIOPUT_CMAP, (unsigned long)(uintptr_t)cmap);
+  if (ret != OK)
+    {
+      fprintf(stderr, "Unable to set camp\n");
+    }
 
-    return ret;
+  return ret;
 }
 
 /****************************************************************************
@@ -332,30 +334,30 @@ static int video_putcmap(int fb, FAR const struct fb_cmap_s *cmap)
 
 static int video_getcmap(int fb, FAR struct fb_cmap_s *cmap)
 {
-    int n;
-    int ret;
+  int n;
+  int ret;
 
-    ret = ioctl(fb, FBIOGET_CMAP, (unsigned long)(uintptr_t)cmap);
-    if (ret != OK)
-      {
-          fprintf(stderr, "Unable to set camp\n");
-      }
+  ret = ioctl(fb, FBIOGET_CMAP, (unsigned long)(uintptr_t)cmap);
+  if (ret != OK)
+    {
+      fprintf(stderr, "Unable to set camp\n");
+    }
 
-    printf("Get cmap\n");
-    for (n = cmap->first; n < cmap->len; n++)
-      {
-          printf("  Color %d: (a,r,g,b) = (%02x,%02x,%02x,%02x)\n", n,
+  printf("Get cmap\n");
+  for (n = cmap->first; n < cmap->len; n++)
+    {
+      printf("  Color %d: (a,r,g,b) = (%02x,%02x,%02x,%02x)\n", n,
 #  ifdef CONFIG_CMAP_TRANSPARENCY
-                 cmap->transp[n],
+             cmap->transp[n],
 #  else
-                 (uint8_t)0xff,
+             (uint8_t)0xff,
 #  endif
-                 cmap->red[n],
-                 cmap->green[n],
-                 cmap->blue[n]);
-      }
+             cmap->red[n],
+             cmap->green[n],
+             cmap->blue[n]);
+    }
 
-    return ret;
+  return ret;
 }
 #endif /* CONFIG_FB_CMAP */
 
@@ -415,8 +417,8 @@ static void print_plane_info(int fb)
       return;
     }
 
-  fbmem = mmap(NULL, pinfo.fblen, PROT_READ|PROT_WRITE,
-      MAP_SHARED|MAP_FILE, fb, 0);
+  fbmem = mmap(NULL, pinfo.fblen, PROT_READ | PROT_WRITE,
+               MAP_SHARED | MAP_FILE, fb, 0);
 
   if (fbmem == MAP_FAILED)
     {
@@ -426,11 +428,13 @@ static void print_plane_info(int fb)
 
   printf("PlaneInfo:\n"
          "    fbmem: %p\n"
-         "    fblen: %lu\n"
+         "    fblen: %zu\n"
          "   stride: %u\n"
          "  display: %u\n"
-         "      bpp: %u\n",
-         pinfo.fbmem, (unsigned long)pinfo.fblen, pinfo.stride, pinfo.display,
+         "      bpp: %u\n"
+         "    fbmem: %p\n",
+         pinfo.fbmem, pinfo.fblen, pinfo.stride,
+         pinfo.display,
          pinfo.bpp, fbmem);
 }
 
@@ -470,8 +474,8 @@ static void print_overlay_info(int fb, uint8_t overlayno)
       return;
     }
 
-  fbmem = mmap(NULL, oinfo.fblen, PROT_READ|PROT_WRITE,
-               MAP_SHARED|MAP_FILE, fb, 0);
+  fbmem = mmap(NULL, oinfo.fblen, PROT_READ | PROT_WRITE,
+               MAP_SHARED | MAP_FILE, fb, 0);
 
   if (fbmem == MAP_FAILED)
     {
@@ -481,18 +485,19 @@ static void print_overlay_info(int fb, uint8_t overlayno)
 
   printf("OverlayInfo:\n"
          "    fbmem: %p\n"
-         "    fblen: %lu\n"
+         "    fblen: %zu\n"
          "   stride: %u\n"
          "  overlay: %u\n"
          "      bpp: %u\n"
          "    blank: %08x\n"
-         "chromakey: %08x\n"
-         "    color: %08x\n"
+         "chromakey: %08" PRIx32 "\n"
+         "    color: %08" PRIx32 "\n"
          "   transp: %02x\n"
          "     mode: %08x\n"
-         "     accl: %08x\n"
+         "     accl: %08" PRIx32 "\n"
          "     mmap: %p\n",
-         oinfo.fbmem, (unsigned long)oinfo.fblen, oinfo.stride, oinfo.overlay,
+         oinfo.fbmem, oinfo.fblen, oinfo.stride,
+         oinfo.overlay,
          oinfo.bpp, oinfo.blank, oinfo.chromakey, oinfo.color,
          oinfo.transp.transp, oinfo.transp.transp_mode, oinfo.accl, fbmem);
 }
@@ -541,8 +546,8 @@ static int overlay_fill(int fb, uint8_t overlayno, uint32_t color,
       return -1;
     }
 
-  fbmem = mmap(NULL, oinfo.fblen, PROT_READ|PROT_WRITE,
-               MAP_SHARED|MAP_FILE, fb, 0);
+  fbmem = mmap(NULL, oinfo.fblen, PROT_READ | PROT_WRITE,
+               MAP_SHARED | MAP_FILE, fb, 0);
 
   if (fbmem == MAP_FAILED)
     {
@@ -556,7 +561,8 @@ static int overlay_fill(int fb, uint8_t overlayno, uint32_t color,
 
       if (offset > oinfo.fblen)
         {
-          fprintf(stderr, "Area is out of range: %d >= %d\n", offset, oinfo.fblen);
+          fprintf(stderr, "Area is out of range: %" PRId32 " >= %zu\n",
+                  offset, oinfo.fblen);
           return -1;
         }
 
@@ -621,7 +627,7 @@ static int overlay_accl(int fb, uint8_t overlayno, uint32_t accl)
       return -1;
     }
 
-  printf("%s: %08x %08x\n", __func__, oinfo.accl, accl);
+  printf("%s: %08" PRIx32 " %08" PRIx32 "\n", __func__, oinfo.accl, accl);
   return (oinfo.accl & accl) ? OK : -1;
 }
 
@@ -641,7 +647,8 @@ static int overlay_color(int fb, FAR struct fb_overlayinfo_s *oinfo)
 {
   int ret;
 
-  printf("Overlay: %d, set color: 0x%08x\n", oinfo->overlay, oinfo->color);
+  printf("Overlay: %d, set color: 0x%08" PRIx32 "\n",
+         oinfo->overlay, oinfo->color);
 
   ret = overlay_accl(fb, oinfo->overlay, FB_ACCL_COLOR);
   if (ret != OK)
@@ -685,7 +692,7 @@ static int overlay_chromakey(int fb, FAR struct fb_overlayinfo_s *oinfo)
 {
   int ret;
 
-  printf("Overlay: %d, set chromakey: 0x%08x\n", oinfo->overlay,
+  printf("Overlay: %d, set chromakey: 0x%08" PRIx32 "\n", oinfo->overlay,
          oinfo->chromakey);
 
   ret = overlay_accl(fb, oinfo->overlay, FB_ACCL_CHROMA);
@@ -736,7 +743,8 @@ static int overlay_transp(int fb, FAR struct fb_overlayinfo_s *oinfo)
   ret = overlay_accl(fb, oinfo->overlay, FB_ACCL_TRANSP);
   if (ret != OK)
     {
-      fprintf(stderr, "No hardware acceleration to set the transparency within "
+      fprintf(stderr,
+              "No hardware acceleration to set the transparency within "
               "the selected overlay area\n");
     }
   else
@@ -893,6 +901,7 @@ static int overlay_blend(int fb, FAR struct fb_overlayblend_s *blend)
     {
       ret = overlay_accl(fb, blend->background.overlay, FB_ACCL_BLEND);
     }
+
   if (ret == OK)
     {
       ret = overlay_accl(fb, blend->dest.overlay, FB_ACCL_BLEND);
@@ -991,7 +1000,8 @@ static void usage(const char * progname)
           "      1 : Off\n"
           "    -area overlayno <xpos> <ypos> <xres> <yres>\n"
 #ifdef CONFIG_FB_OVERLAY_BLIT
-          "    -blit doverlayno <destxpos> <destypos> <destxres> <destyres>\n"
+          "    -blit doverlayno <destxpos> <destypos> <destxres> "
+          "<destyres>\n"
           "          soverlayno <srcxpos> <srcypos> <srcxres> <srcyres>\n"
           "    -blend doverlayno <dxpos> <dypos> <dxres> <dyres>\n"
           "           foverlayno <fxpos> <fypos> <fxres> <fyres>\n"
@@ -1012,7 +1022,6 @@ static void usage(const char * progname)
 
 int main(int argc, FAR char *argv[])
 {
-
   char *fbdevice;
   int  fb = -1;
 
@@ -1092,21 +1101,26 @@ int main(int argc, FAR char *argv[])
           rgb8888(strtoul(argv[3], NULL, 16), &a[1], &r[1], &g[1], &b[1]);
           cmap.len = 2;
         }
+
       if (argc >= 4)
         {
           rgb8888(strtoul(argv[4], NULL, 16), &a[2], &r[2], &g[2], &b[2]);
           cmap.len = 3;
         }
+
       if (argc >= 5)
+
         {
           rgb8888(strtoul(argv[5], NULL, 16), &a[3], &r[3], &g[3], &b[3]);
           cmap.len = 4;
         }
+
       if (argc >= 6)
         {
           rgb8888(strtoul(argv[6], NULL, 16), &a[4], &r[4], &g[4], &b[4]);
           cmap.len = 5;
         }
+
 #  ifdef CONFIG_FB_TRANSPARENCY
       cmap.transp = a;
 #  endif
