@@ -67,7 +67,9 @@
  ****************************************************************************/
 
 static bool started;
-static int sd, sd2, sd3;
+static int sd;
+static int sd2;
+static int sd3;
 
 /****************************************************************************
  * Public Data
@@ -78,7 +80,7 @@ static int sd, sd2, sd3;
  ****************************************************************************/
 
 /****************************************************************************
- * Name: NoActiveSockets
+ * Name: no_active_sockets
  *
  * Description:
  *   Checks there is no active sockets on daemon startup
@@ -94,7 +96,7 @@ static int sd, sd2, sd3;
  *
  ****************************************************************************/
 
-static void NoActiveSockets(FAR struct usrsocktest_daemon_conf_s *dconf)
+static void no_active_sockets(FAR struct usrsocktest_daemon_conf_s *dconf)
 {
   TEST_ASSERT_EQUAL(OK, usrsocktest_daemon_start(dconf));
   started = true;
@@ -103,7 +105,7 @@ static void NoActiveSockets(FAR struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: OpenClose
+ * Name: open_close
  *
  * Description:
  *   Open and close AF_INET socket, check active socket counter updates
@@ -119,7 +121,7 @@ static void NoActiveSockets(FAR struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void OpenClose(FAR struct usrsocktest_daemon_conf_s *dconf)
+static void open_close(FAR struct usrsocktest_daemon_conf_s *dconf)
 {
   TEST_ASSERT_EQUAL(OK, usrsocktest_daemon_start(dconf));
   started = true;
@@ -139,7 +141,7 @@ static void OpenClose(FAR struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: UnsupportedType
+ * Name: unsupported_type
  *
  * Description:
  *   Try open socket for unsupported type
@@ -155,7 +157,7 @@ static void OpenClose(FAR struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void UnsupportedType(FAR struct usrsocktest_daemon_conf_s *dconf)
+static void unsupported_type(FAR struct usrsocktest_daemon_conf_s *dconf)
 {
   TEST_ASSERT_EQUAL(OK, usrsocktest_daemon_start(dconf));
   started = true;
@@ -172,7 +174,7 @@ static void UnsupportedType(FAR struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: UnsupportedProto
+ * Name: unsupported_proto
  *
  * Description:
  *   Try open socket for unsupported protocol
@@ -188,7 +190,7 @@ static void UnsupportedType(FAR struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void UnsupportedProto(FAR struct usrsocktest_daemon_conf_s *dconf)
+static void unsupported_proto(FAR struct usrsocktest_daemon_conf_s *dconf)
 {
   TEST_ASSERT_EQUAL(OK, usrsocktest_daemon_start(dconf));
   started = true;
@@ -205,7 +207,7 @@ static void UnsupportedProto(FAR struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: OpenThree
+ * Name: open_three
  *
  * Description:
  *   Open multiple sockets
@@ -221,7 +223,7 @@ static void UnsupportedProto(FAR struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void OpenThree(FAR struct usrsocktest_daemon_conf_s *dconf)
+static void open_three(FAR struct usrsocktest_daemon_conf_s *dconf)
 {
   int ret;
 
@@ -262,10 +264,10 @@ static void OpenThree(FAR struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: Dup
+ * Name: basic_daemon_dup
  *
  * Description:
- *   Dup opened socket
+ *   basic_daemon_dup opened socket
  *
  * Input Parameters:
  *   None
@@ -278,7 +280,7 @@ static void OpenThree(FAR struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void Dup(FAR struct usrsocktest_daemon_conf_s *dconf)
+static void basic_daemon_dup(FAR struct usrsocktest_daemon_conf_s *dconf)
 {
   int ret;
 
@@ -317,7 +319,7 @@ static void Dup(FAR struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: Dup2
+ * Name: basic_daemon_dup2
  *
  * Description:
  *   Clone opened socket with dup2
@@ -333,7 +335,7 @@ static void Dup(FAR struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void Dup2(FAR struct usrsocktest_daemon_conf_s *dconf)
+static void basic_daemon_dup2(FAR struct usrsocktest_daemon_conf_s *dconf)
 {
   int ret;
 
@@ -367,7 +369,7 @@ static void Dup2(FAR struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: Stops
+ * Name: stops
  *
  * Description:
  *   Daemon stops unexpectedly
@@ -383,7 +385,7 @@ static void Dup2(FAR struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void Stops(FAR struct usrsocktest_daemon_conf_s *dconf)
+static void stops(FAR struct usrsocktest_daemon_conf_s *dconf)
 {
   int ret;
 
@@ -404,7 +406,6 @@ static void Stops(FAR struct usrsocktest_daemon_conf_s *dconf)
   TEST_ASSERT_EQUAL(0, usrsocktest_endp_malloc_cnt);
   TEST_ASSERT_EQUAL(0, usrsocktest_dcmd_malloc_cnt);
 
-
   TEST_ASSERT_EQUAL(0, close(sd));
   sd = -1;
   TEST_ASSERT_EQUAL(0, close(sd2));
@@ -412,7 +413,7 @@ static void Stops(FAR struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: StopsStarts
+ * Name: stops_starts
  *
  * Description:
  *   Daemon stops and restarts unexpectedly
@@ -428,7 +429,7 @@ static void Stops(FAR struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void StopsStarts(FAR struct usrsocktest_daemon_conf_s *dconf)
+static void stops_starts(FAR struct usrsocktest_daemon_conf_s *dconf)
 {
   int ret;
   struct sockaddr_in addr;
@@ -475,7 +476,7 @@ static void StopsStarts(FAR struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: BasicDaemon test group setup
+ * Name: basic_daemon test group setup
  *
  * Description:
  *   Setup function executed before each testcase in this test group
@@ -491,7 +492,7 @@ static void StopsStarts(FAR struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-TEST_SETUP(BasicDaemon)
+TEST_SETUP(basic_daemon)
 {
   sd = -1;
   sd2 = -1;
@@ -500,7 +501,7 @@ TEST_SETUP(BasicDaemon)
 }
 
 /****************************************************************************
- * Name: BasicDaemon test group teardown
+ * Name: basic_daemon test group teardown
  *
  * Description:
  *   Setup function executed after each testcase in this test group
@@ -516,7 +517,7 @@ TEST_SETUP(BasicDaemon)
  *
  ****************************************************************************/
 
-TEST_TEAR_DOWN(BasicDaemon)
+TEST_TEAR_DOWN(basic_daemon)
 {
   int ret;
   if (sd >= 0)
@@ -524,16 +525,19 @@ TEST_TEAR_DOWN(BasicDaemon)
       ret = close(sd);
       assert(ret >= 0);
     }
+
   if (sd2 >= 0)
     {
       ret = close(sd2);
       assert(ret >= 0);
     }
+
   if (sd3 >= 0)
     {
       ret = close(sd3);
       assert(ret >= 0);
     }
+
   if (started)
     {
       ret = usrsocktest_daemon_stop();
@@ -541,145 +545,145 @@ TEST_TEAR_DOWN(BasicDaemon)
     }
 }
 
-TEST(BasicDaemon, NoActiveSockets)
+TEST(basic_daemon, no_active_sockets)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  NoActiveSockets(&usrsocktest_daemon_config);
+  no_active_sockets(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, NoActiveSocketsDelay)
+TEST(basic_daemon, no_active_sockets_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  NoActiveSockets(&usrsocktest_daemon_config);
+  no_active_sockets(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, OpenClose)
+TEST(basic_daemon, open_close)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  OpenClose(&usrsocktest_daemon_config);
+  open_close(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, OpenCloseDelay)
+TEST(basic_daemon, open_close_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  OpenClose(&usrsocktest_daemon_config);
+  open_close(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, UnsupportedType)
+TEST(basic_daemon, unsupported_type)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  UnsupportedType(&usrsocktest_daemon_config);
+  unsupported_type(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, UnsupportedTypeDelay)
+TEST(basic_daemon, unsupported_type_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  UnsupportedType(&usrsocktest_daemon_config);
+  unsupported_type(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, UnsupportedProto)
+TEST(basic_daemon, unsupported_proto)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  UnsupportedProto(&usrsocktest_daemon_config);
+  unsupported_proto(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, UnsupportedProtoDelay)
+TEST(basic_daemon, unsupported_proto_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  UnsupportedProto(&usrsocktest_daemon_config);
+  unsupported_proto(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, OpenThree)
+TEST(basic_daemon, open_three)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  OpenThree(&usrsocktest_daemon_config);
+  open_three(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, OpenThreeDelay)
+TEST(basic_daemon, open_three_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  OpenThree(&usrsocktest_daemon_config);
+  open_three(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, Dup)
+TEST(basic_daemon, basic_daemon_dup)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  Dup(&usrsocktest_daemon_config);
+  basic_daemon_dup(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, DupDelay)
+TEST(basic_daemon, basic_daemon_dup_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  Dup(&usrsocktest_daemon_config);
+  basic_daemon_dup(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, Dup2)
+TEST(basic_daemon, basic_daemon_dup2)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  Dup2(&usrsocktest_daemon_config);
+  basic_daemon_dup2(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, Dup2Delay)
+TEST(basic_daemon, basic_daemon_dup2_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  Dup2(&usrsocktest_daemon_config);
+  basic_daemon_dup2(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, Stops)
+TEST(basic_daemon, stops)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  Stops(&usrsocktest_daemon_config);
+  stops(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, StopsDelay)
+TEST(basic_daemon, stops_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  Stops(&usrsocktest_daemon_config);
+  stops(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, StopsStarts)
+TEST(basic_daemon, stops_starts)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  StopsStarts(&usrsocktest_daemon_config);
+  stops_starts(&usrsocktest_daemon_config);
 }
 
-TEST(BasicDaemon, StopsStartsDelay)
+TEST(basic_daemon, stops_starts_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  StopsStarts(&usrsocktest_daemon_config);
+  stops_starts(&usrsocktest_daemon_config);
 }
 
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
 
-TEST_GROUP(BasicDaemon)
+TEST_GROUP(basic_daemon)
 {
-  RUN_TEST_CASE(BasicDaemon, NoActiveSockets);
-  RUN_TEST_CASE(BasicDaemon, NoActiveSocketsDelay);
-  RUN_TEST_CASE(BasicDaemon, OpenClose);
-  RUN_TEST_CASE(BasicDaemon, OpenCloseDelay);
-  RUN_TEST_CASE(BasicDaemon, UnsupportedType);
-  RUN_TEST_CASE(BasicDaemon, UnsupportedTypeDelay);
-  RUN_TEST_CASE(BasicDaemon, UnsupportedProto);
-  RUN_TEST_CASE(BasicDaemon, UnsupportedProtoDelay);
-  RUN_TEST_CASE(BasicDaemon, OpenThree);
-  RUN_TEST_CASE(BasicDaemon, OpenThreeDelay);
-  RUN_TEST_CASE(BasicDaemon, Dup);
-  RUN_TEST_CASE(BasicDaemon, DupDelay);
-  RUN_TEST_CASE(BasicDaemon, Dup2);
-  RUN_TEST_CASE(BasicDaemon, Dup2Delay);
-  RUN_TEST_CASE(BasicDaemon, Stops);
-  RUN_TEST_CASE(BasicDaemon, StopsDelay);
-  RUN_TEST_CASE(BasicDaemon, StopsStarts);
-  RUN_TEST_CASE(BasicDaemon, StopsStartsDelay);
+  RUN_TEST_CASE(basic_daemon, no_active_sockets);
+  RUN_TEST_CASE(basic_daemon, no_active_sockets_delay);
+  RUN_TEST_CASE(basic_daemon, open_close);
+  RUN_TEST_CASE(basic_daemon, open_close_delay);
+  RUN_TEST_CASE(basic_daemon, unsupported_type);
+  RUN_TEST_CASE(basic_daemon, unsupported_type_delay);
+  RUN_TEST_CASE(basic_daemon, unsupported_proto);
+  RUN_TEST_CASE(basic_daemon, unsupported_proto_delay);
+  RUN_TEST_CASE(basic_daemon, open_three);
+  RUN_TEST_CASE(basic_daemon, open_three_delay);
+  RUN_TEST_CASE(basic_daemon, basic_daemon_dup);
+  RUN_TEST_CASE(basic_daemon, basic_daemon_dup_delay);
+  RUN_TEST_CASE(basic_daemon, basic_daemon_dup2);
+  RUN_TEST_CASE(basic_daemon, basic_daemon_dup2_delay);
+  RUN_TEST_CASE(basic_daemon, stops);
+  RUN_TEST_CASE(basic_daemon, stops_delay);
+  RUN_TEST_CASE(basic_daemon, stops_starts);
+  RUN_TEST_CASE(basic_daemon, stops_starts_delay);
 }
