@@ -78,7 +78,7 @@ static int sd;
  ****************************************************************************/
 
 /****************************************************************************
- * Name: Receive
+ * Name: receive
  *
  * Description:
  *   Non-blocking & instant connect+recv
@@ -94,7 +94,7 @@ static int sd;
  *
  ****************************************************************************/
 
-static void Receive(struct usrsocktest_daemon_conf_s *dconf)
+static void receive(struct usrsocktest_daemon_conf_s *dconf)
 {
   int flags;
   int count;
@@ -149,7 +149,7 @@ static void Receive(struct usrsocktest_daemon_conf_s *dconf)
       TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
       TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_connected_sockets());
       TEST_ASSERT_EQUAL(0,
-                        usrsocktest_daemon_get_num_waiting_connect_sockets());
+                      usrsocktest_daemon_get_num_waiting_connect_sockets());
       TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_recv_empty_sockets());
     }
   else
@@ -159,7 +159,7 @@ static void Receive(struct usrsocktest_daemon_conf_s *dconf)
       TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
       TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_connected_sockets());
       TEST_ASSERT_EQUAL(0,
-                        usrsocktest_daemon_get_num_waiting_connect_sockets());
+                      usrsocktest_daemon_get_num_waiting_connect_sockets());
 
       for (count = 0; usrsocktest_daemon_get_num_connected_sockets() != 1;
            count++)
@@ -230,11 +230,13 @@ static void Receive(struct usrsocktest_daemon_conf_s *dconf)
   /* Reset recv buffer for open sockets */
 
   TEST_ASSERT_TRUE(usrsocktest_send_delayed_command('r', 0));
-  for (count = 0; usrsocktest_daemon_get_num_recv_empty_sockets() > 0; count++)
+  for (count = 0;
+       usrsocktest_daemon_get_num_recv_empty_sockets() > 0; count++)
     {
       TEST_ASSERT_TRUE(count <= 5);
       usleep(5 * 1000);
     }
+
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_recv_empty_sockets());
 
   /* Receive data from remote, daemon returns 4 bytes. */
@@ -270,7 +272,7 @@ static void Receive(struct usrsocktest_daemon_conf_s *dconf)
 }
 
 /****************************************************************************
- * Name: DelayedConnect
+ * Name: delayed_connect
  *
  * Description:
  *   Non-blocking & delayed connect
@@ -286,7 +288,7 @@ static void Receive(struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-static void DelayedConnect(struct usrsocktest_daemon_conf_s *dconf)
+static void delayed_connect(struct usrsocktest_daemon_conf_s *dconf)
 {
   int flags;
   int count;
@@ -330,7 +332,9 @@ static void DelayedConnect(struct usrsocktest_daemon_conf_s *dconf)
   TEST_ASSERT_EQUAL(O_RDWR, flags & O_RDWR);
   TEST_ASSERT_EQUAL(O_NONBLOCK, flags & O_NONBLOCK);
 
-  /* Launch connect attempt, daemon delays actual connection until triggered. */
+  /* Launch connect attempt, daemon delays actual connection until
+   * triggered.
+   */
 
   inet_pton(AF_INET, "127.0.0.1", &addr.sin_addr.s_addr);
   addr.sin_family = AF_INET;
@@ -363,6 +367,7 @@ static void DelayedConnect(struct usrsocktest_daemon_conf_s *dconf)
       TEST_ASSERT_TRUE(count <= 5);
       usleep(10 * 1000);
     }
+
   TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_active_sockets());
   TEST_ASSERT_EQUAL(1, usrsocktest_daemon_get_num_connected_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_daemon_get_num_waiting_connect_sockets());
@@ -386,7 +391,8 @@ static void DelayedConnect(struct usrsocktest_daemon_conf_s *dconf)
   /* Reset recv buffer for open sockets */
 
   TEST_ASSERT_TRUE(usrsocktest_send_delayed_command('r', 0));
-  for (count = 0; usrsocktest_daemon_get_num_recv_empty_sockets() > 0; count++)
+  for (count = 0;
+       usrsocktest_daemon_get_num_recv_empty_sockets() > 0; count++)
     {
       TEST_ASSERT_TRUE(count <= 5);
       usleep(5 * 1000);
@@ -422,13 +428,14 @@ static void DelayedConnect(struct usrsocktest_daemon_conf_s *dconf)
   TEST_ASSERT_EQUAL(-ENODEV, usrsocktest_daemon_get_num_connected_sockets());
   TEST_ASSERT_EQUAL(-ENODEV,
                     usrsocktest_daemon_get_num_waiting_connect_sockets());
-  TEST_ASSERT_EQUAL(-ENODEV, usrsocktest_daemon_get_num_recv_empty_sockets());
+  TEST_ASSERT_EQUAL(-ENODEV,
+                    usrsocktest_daemon_get_num_recv_empty_sockets());
   TEST_ASSERT_EQUAL(0, usrsocktest_endp_malloc_cnt);
   TEST_ASSERT_EQUAL(0, usrsocktest_dcmd_malloc_cnt);
 }
 
 /****************************************************************************
- * Name: NoBlockRecv test group setup
+ * Name: no_block_recv test group setup
  *
  * Description:
  *   Setup function executed before each testcase in this test group
@@ -444,14 +451,14 @@ static void DelayedConnect(struct usrsocktest_daemon_conf_s *dconf)
  *
  ****************************************************************************/
 
-TEST_SETUP(NoBlockRecv)
+TEST_SETUP(no_block_recv)
 {
   sd = -1;
   started = false;
 }
 
 /****************************************************************************
- * Name: NoBlockRecv test group teardown
+ * Name: no_block_recv test group teardown
  *
  * Description:
  *   Setup function executed after each testcase in this test group
@@ -467,7 +474,7 @@ TEST_SETUP(NoBlockRecv)
  *
  ****************************************************************************/
 
-TEST_TEAR_DOWN(NoBlockRecv)
+TEST_TEAR_DOWN(no_block_recv)
 {
   int ret;
   if (sd >= 0)
@@ -475,6 +482,7 @@ TEST_TEAR_DOWN(NoBlockRecv)
       ret = close(sd);
       assert(ret >= 0);
     }
+
   if (started)
     {
       ret = usrsocktest_daemon_stop();
@@ -482,40 +490,40 @@ TEST_TEAR_DOWN(NoBlockRecv)
     }
 }
 
-TEST(NoBlockRecv, Receive)
+TEST(no_block_recv, receive)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  Receive(&usrsocktest_daemon_config);
+  receive(&usrsocktest_daemon_config);
 }
 
-TEST(NoBlockRecv, ReceiveDelay)
+TEST(no_block_recv, receive_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  Receive(&usrsocktest_daemon_config);
+  receive(&usrsocktest_daemon_config);
 }
 
-TEST(NoBlockRecv, DelayedConnect)
+TEST(no_block_recv, delayed_connect)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
-  DelayedConnect(&usrsocktest_daemon_config);
+  delayed_connect(&usrsocktest_daemon_config);
 }
 
-TEST(NoBlockRecv, DelayedConnectDelay)
+TEST(no_block_recv, delayed_connect_delay)
 {
   usrsocktest_daemon_config = usrsocktest_daemon_defconf;
   usrsocktest_daemon_config.delay_all_responses = true;
-  DelayedConnect(&usrsocktest_daemon_config);
+  delayed_connect(&usrsocktest_daemon_config);
 }
 
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
 
-TEST_GROUP(NoBlockRecv)
+TEST_GROUP(no_block_recv)
 {
-  RUN_TEST_CASE(NoBlockRecv, Receive);
-  RUN_TEST_CASE(NoBlockRecv, ReceiveDelay);
-  RUN_TEST_CASE(NoBlockRecv, DelayedConnect);
-  RUN_TEST_CASE(NoBlockRecv, DelayedConnectDelay);
+  RUN_TEST_CASE(no_block_recv, receive);
+  RUN_TEST_CASE(no_block_recv, receive_delay);
+  RUN_TEST_CASE(no_block_recv, delayed_connect);
+  RUN_TEST_CASE(no_block_recv, delayed_connect_delay);
 }
