@@ -37,6 +37,7 @@
  * Included Files
  ****************************************************************************/
 
+#include <cinttypes>
 #include <cunistd>
 #include <cerrno>
 
@@ -1241,7 +1242,8 @@ bool CCalibration::createCalibrationData(struct SCalibrationData &data)
   data.xSlope  = b16divb16(itob16(CALIBRATION_RIGHTX - CALIBRATION_LEFTX), (rightX - leftX));
   data.xOffset = itob16(CALIBRATION_LEFTX) - b16mulb16(leftX, data.xSlope);
 
-  iinfo("New xSlope: %08x xOffset: %08x\n", data.xSlope, data.xOffset);
+  iinfo("New xSlope: %08" PRIx32 " xOffset: %08" PRIx32 "\n",
+        data.xSlope, data.xOffset);
 
   // Similarly for Y
   //
@@ -1262,7 +1264,8 @@ bool CCalibration::createCalibrationData(struct SCalibrationData &data)
   data.ySlope  = b16divb16(itob16(CALIBRATION_BOTTOMY - CALIBRATION_TOPY), (bottomY - topY));
   data.yOffset = itob16(CALIBRATION_TOPY) - b16mulb16(topY, data.ySlope);
 
-  iinfo("New ySlope: %08x yOffset: %08x\n", data.ySlope, data.yOffset);
+  iinfo("New ySlope: %08" PRIx32 " yOffset: %08" PRIx32 "\n",
+        data.ySlope, data.yOffset);
 #endif
 
   return true;
