@@ -56,22 +56,6 @@
 
 #include "ftpc_internal.h"
 
-/****************************************************************************
- * Pre-processor Definitions
- ****************************************************************************/
-
-/****************************************************************************
- * Private Types
- ****************************************************************************/
-
-/****************************************************************************
- * Private Data
- ****************************************************************************/
-
-/****************************************************************************
- * Public Data
- ****************************************************************************/
-
 /****************************************************************************
  * Private Functions
  ****************************************************************************/
@@ -557,7 +541,11 @@ int ftpc_xfrmode(struct ftpc_session_s *session, uint8_t xfrmode)
 
       ret = ftpc_cmd(session, "TYPE %c",
                      xfrmode == FTPC_XFRMODE_ASCII ? 'A' : 'I');
-      UNUSED(ret);
+      if (ret < 0)
+        {
+          return ERROR;
+        }
+
       session->xfrmode = xfrmode;
     }
 
