@@ -1,34 +1,21 @@
 /****************************************************************************
  * apps/netutils/netinit/netinit.c
  *
- *   Copyright (C) 2010-2012, 2014-2016, 2019 Gregory Nutt. All rights
- *     reserved.
- *   Author: Gregory Nutt <gnutt@nuttx.org>
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.  The
+ * ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the
+ * License.  You may obtain a copy of the License at
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. Neither the name of the Institute nor the names of its contributors
- *    may be used to endorse or promote products derived from this software
- *    without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+
  ****************************************************************************/
 
 /****************************************************************************
@@ -63,7 +50,7 @@
 #include <nuttx/net/mii.h>
 
 #include "netutils/netlib.h"
-#if defined(CONFIG_NETINIT_DHCPC) || defined(CONFIG_NETINIT_DNS)
+#if defined(CONFIG_NETUTILS_DHCPC) || defined(CONFIG_NETINIT_DNS)
 #  include "netutils/dhcpc.h"
 #endif
 
@@ -79,6 +66,10 @@
 #  include "netutils/ntpclient.h"
 #endif
 
+#if defined(CONFIG_FSUTILS_IPCFG)
+#  include "fsutils/ipcfg.h"
+#endif
+
 #include "netutils/netinit.h"
 
 #ifdef CONFIG_NETUTILS_NETINIT
@@ -237,6 +228,10 @@
 static sem_t g_notify_sem;
 #endif
 
+#ifdef CONFIG_NETUTILS_DHCPC
+bool g_use_dhcpc;
+#endif
+
 #if defined(CONFIG_NET_IPv6) && !defined(CONFIG_NET_ICMPv6_AUTOCONF) && \
    !defined(CONFIG_NET_6LOWPAN)
 /* Host IPv6 address */
@@ -295,7 +290,8 @@ static const uint16_t g_ipv6_netmask[8] =
  *
  ****************************************************************************/
 
-#if defined(NETINIT_HAVE_NETDEV) && defined(CONFIG_NETINIT_NOMAC) && defined(HAVE_MAC)
+#if defined(NETINIT_HAVE_NETDEV) && defined(CONFIG_NETINIT_NOMAC) && \
+    defined(HAVE_MAC)
 static void netinit_set_macaddr(void)
 {
 #if defined(CONFIG_NET_ETHERNET)
@@ -343,6 +339,221 @@ static void netinit_set_macaddr(void)
 #  define netinit_set_macaddr()
 #endif
 
+/****************************************************************************
+ * Name: netinit_set_ipv4addrs
+ *
+ * Description:
+ *   Setup IPv4 addresses.
+ *
+ ****************************************************************************/
+
+#if defined(NETINIT_HAVE_NETDEV) && !defined(CONFIG_NET_6LOWPAN) && ! \
+    defined(CONFIG_NET_IEEE802154) && defined(CONFIG_NET_IPv4)
+static inline void netinit_set_ipv4addrs(void)
+{
+  struct in_addr addr;
+#ifdef CONFIG_FSUTILS_IPCFG
+  struct ipv4cfg_s ipv4cfg;
+  int ret;
+
+  /* Attempt to obtain IPv4 address configuration from the IP configuration
+   * file.
+   */
+
+  ret = ipcfg_read(NET_DEVNAME, (FAR struct ipcfg_s *)&ipv4cfg, AF_INET);
+#ifdef CONFIG_NETUTILS_DHCPC
+  if (ret >= 0 && ipv4cfg.proto != IPv4PROTO_NONE)
+#else
+  if (ret >= 0 && IPCFG_HAVE_STATIC(ipv4cfg.proto))
+#endif
+    {
+      /* Check if we are using DHCPC */
+
+#ifdef CONFIG_NETUTILS_DHCPC
+      if (IPCFG_USE_DHCP(ipv4cfg.proto))
+        {
+          g_use_dhcpc = true;
+          addr.s_addr = 0;
+        }
+      else
+#endif
+        {
+          /* We are not using DHCPC.  We need an IP address */
+
+#ifdef CONFIG_NETINIT_IPADDR
+          /* Check if we have a static IP address in the configuration file */
+
+          if (IPCFG_HAVE_STATIC(ipv4cfg.proto))
+            {
+              addr.s_addr = ipv4cfg.ipaddr;
+            }
+          else
+            {
+              /* This is not a good option, but in this case what else can
+               * we do?
+               */
+
+              addr.s_addr = HTONL(CONFIG_NETINIT_IPADDR);
+            }
+#else
+          /* Use whatever was provided in the file (might be zero) */
+
+          addr.s_addr = ipv4cfg.ipaddr;
+#endif
+        }
+
+      netlib_set_ipv4addr(NET_DEVNAME, &addr);
+
+      /* Set up the remaining addresses */
+
+      if (IPCFG_HAVE_STATIC(ipv4cfg.proto))
+        {
+          /* Set up the default router address */
+
+          addr.s_addr = ipv4cfg.router;
+          netlib_set_dripv4addr(NET_DEVNAME, &addr);
+
+          /* Setup the subnet mask */
+
+          addr.s_addr = ipv4cfg.netmask;
+          netlib_set_ipv4netmask(NET_DEVNAME, &addr);
+        }
+
+#ifdef CONFIG_NETUTILS_DHCPC
+      /* No static addresses?  That is fine if we are have addresses
+       * provided by the configuration, or if we are using DHCP.
+       */
+
+      else if (g_use_dhcpc)
+        {
+          /* Set up the default router address and sub-net mask */
+
+          addr.s_addr = 0;
+          netlib_set_dripv4addr(NET_DEVNAME, &addr);
+          netlib_set_ipv4netmask(NET_DEVNAME, &addr);
+        }
+#endif
+      else
+        {
+          /* Otherwise, set up the configured default router address */
+
+          addr.s_addr = HTONL(CONFIG_NETINIT_DRIPADDR);
+          netlib_set_dripv4addr(NET_DEVNAME, &addr);
+
+          /* Setup the subnet mask */
+
+          addr.s_addr = HTONL(CONFIG_NETINIT_NETMASK);
+          netlib_set_ipv4netmask(NET_DEVNAME, &addr);
+        }
+
+#ifdef CONFIG_NETINIT_DNS
+      /* Set up the DNS address.  Was one provided in the configuration? */
+
+      if (ipv4cfg.dnsaddr == 0)
+        {
+          /* No, use the configured default */
+
+          addr.s_addr = HTONL(CONFIG_NETINIT_DNSIPADDR);
+        }
+      else
+        {
+          addr.s_addr = ipv4cfg.dnsaddr;
+        }
+
+      netlib_set_ipv4dnsaddr(&addr);
+#endif
+    }
+  else
+#endif
+    {
+      /* Set up our host address */
+
+#ifdef CONFIG_NETINIT_DHCPC
+      g_use_dhcpc = true;
+      addr.s_addr = 0;
+#else
+      addr.s_addr = HTONL(CONFIG_NETINIT_IPADDR);
+#endif
+      netlib_set_ipv4addr(NET_DEVNAME, &addr);
+
+      /* Set up the default router address */
+
+      addr.s_addr = HTONL(CONFIG_NETINIT_DRIPADDR);
+      netlib_set_dripv4addr(NET_DEVNAME, &addr);
+
+      /* Setup the subnet mask */
+
+      addr.s_addr = HTONL(CONFIG_NETINIT_NETMASK);
+      netlib_set_ipv4netmask(NET_DEVNAME, &addr);
+
+#ifdef CONFIG_NETINIT_DNS
+      addr.s_addr = HTONL(CONFIG_NETINIT_DNSIPADDR);
+      netlib_set_ipv4dnsaddr(&addr);
+#endif
+    }
+}
+#endif
+
+/****************************************************************************
+ * Name: netinit_set_ipv6addrs
+ *
+ * Description:
+ *   Setup IPv6 addresses.
+ *
+ ****************************************************************************/
+
+#if defined(NETINIT_HAVE_NETDEV) && !defined(CONFIG_NET_6LOWPAN) && ! \
+    defined(CONFIG_NET_IEEE802154) && defined(CONFIG_NET_IPv6)
+static inline void netinit_set_ipv6addrs(void)
+{
+#ifndef CONFIG_NET_ICMPv6_AUTOCONF
+#ifdef CONFIG_FSUTILS_IPCFG
+  struct ipv6cfg_s ipv6cfg;
+  int ret;
+#endif
+
+#ifdef CONFIG_FSUTILS_IPCFG
+  /* Attempt to obtain IPv6 address configuration from the IP configuration
+   * file.
+   */
+
+  ret = ipcfg_read(NET_DEVNAME, (FAR struct ipcfg_s *)&ipv6cfg, AF_INET6);
+  if (ret >= 0 && IPCFG_HAVE_STATIC(ipv6cfg.proto))
+    {
+      /* Set up our fixed host address */
+
+      netlib_set_ipv6addr(NET_DEVNAME, &ipv6cfg.ipaddr);
+
+      /* Set up the default router address */
+
+      netlib_set_dripv6addr(NET_DEVNAME, &ipv6cfg.router);
+
+      /* Setup the subnet mask */
+
+      netlib_set_ipv6netmask(NET_DEVNAME, &ipv6cfg.netmask);
+    }
+  else
+#endif
+    {
+      /* Set up our fixed host address */
+
+      netlib_set_ipv6addr(NET_DEVNAME,
+                          (FAR const struct in6_addr *)g_ipv6_hostaddr);
+
+      /* Set up the default router address */
+
+      netlib_set_dripv6addr(NET_DEVNAME,
+                            (FAR const struct in6_addr *)g_ipv6_draddr);
+
+      /* Setup the subnet mask */
+
+      netlib_set_ipv6netmask(NET_DEVNAME,
+                            (FAR const struct in6_addr *)g_ipv6_netmask);
+    }
+#endif /* CONFIG_NET_ICMPv6_AUTOCONF */
+}
+#endif
+
 /****************************************************************************
  * Name: netinit_set_ipaddrs
  *
@@ -359,51 +570,11 @@ static void netinit_set_macaddr(void)
 static void netinit_set_ipaddrs(void)
 {
 #ifdef CONFIG_NET_IPv4
-  struct in_addr addr;
-
-  /* Set up our host address */
-
-#ifndef CONFIG_NETINIT_DHCPC
-  addr.s_addr = HTONL(CONFIG_NETINIT_IPADDR);
-#else
-  addr.s_addr = 0;
-#endif
-  netlib_set_ipv4addr(NET_DEVNAME, &addr);
-
-  /* Set up the default router address */
-
-  addr.s_addr = HTONL(CONFIG_NETINIT_DRIPADDR);
-  netlib_set_dripv4addr(NET_DEVNAME, &addr);
-
-  /* Setup the subnet mask */
-
-  addr.s_addr = HTONL(CONFIG_NETINIT_NETMASK);
-  netlib_set_ipv4netmask(NET_DEVNAME, &addr);
+  netinit_set_ipv4addrs();
 #endif
 
 #ifdef CONFIG_NET_IPv6
-#ifndef CONFIG_NET_ICMPv6_AUTOCONF
-  /* Set up our fixed host address */
-
-  netlib_set_ipv6addr(NET_DEVNAME,
-                      (FAR const struct in6_addr *)g_ipv6_hostaddr);
-
-  /* Set up the default router address */
-
-  netlib_set_dripv6addr(NET_DEVNAME,
-                        (FAR const struct in6_addr *)g_ipv6_draddr);
-
-  /* Setup the subnet mask */
-
-  netlib_set_ipv6netmask(NET_DEVNAME,
-                        (FAR const struct in6_addr *)g_ipv6_netmask);
-
-#endif /* CONFIG_NET_ICMPv6_AUTOCONF */
-#endif /* CONFIG_NET_IPv6 */
-
-#ifdef CONFIG_NETINIT_DNS
-  addr.s_addr = HTONL(CONFIG_NETINIT_DNSIPADDR);
-  netlib_set_ipv4dnsaddr(&addr);
+  netinit_set_ipv6addrs();
 #endif
 }
 #else
@@ -421,7 +592,7 @@ static void netinit_set_ipaddrs(void)
 #if defined(NETINIT_HAVE_NETDEV) && !defined(CONFIG_NETINIT_NETLOCAL)
 static void netinit_net_bringup(void)
 {
-#ifdef CONFIG_NETINIT_DHCPC
+#ifdef CONFIG_NETUTILS_DHCPC
   uint8_t mac[IFHWADDRLEN];
   struct dhcpc_state ds;
   FAR void *handle;
@@ -449,45 +620,48 @@ static void netinit_net_bringup(void)
   netlib_icmpv6_autoconfiguration(NET_DEVNAME);
 #endif
 
-#ifdef CONFIG_NETINIT_DHCPC
-  /* Get the MAC address of the NIC */
-
-  netlib_getmacaddr(NET_DEVNAME, mac);
-
-  /* Set up the DHCPC modules */
-
-  handle = dhcpc_open(NET_DEVNAME, &mac, IFHWADDRLEN);
-  if (handle == NULL)
+#ifdef CONFIG_NETUTILS_DHCPC
+  if (g_use_dhcpc)
     {
-      return;
+      /* Get the MAC address of the NIC */
+
+      netlib_getmacaddr(NET_DEVNAME, mac);
+
+      /* Set up the DHCPC modules */
+
+      handle = dhcpc_open(NET_DEVNAME, &mac, IFHWADDRLEN);
+      if (handle == NULL)
+        {
+          return;
+        }
+
+      /* Get an IP address.  Note that there is no logic for renewing the
+       * IP address in this example. The address should be renewed in
+       * (ds.lease_time / 2) seconds.
+       */
+
+      if (dhcpc_request(handle, &ds) == OK)
+        {
+          netlib_set_ipv4addr(NET_DEVNAME, &ds.ipaddr);
+
+          if (ds.netmask.s_addr != 0)
+            {
+              netlib_set_ipv4netmask(NET_DEVNAME, &ds.netmask);
+            }
+
+          if (ds.default_router.s_addr != 0)
+            {
+              netlib_set_dripv4addr(NET_DEVNAME, &ds.default_router);
+            }
+
+          if (ds.dnsaddr.s_addr != 0)
+            {
+              netlib_set_ipv4dnsaddr(&ds.dnsaddr);
+            }
+        }
+
+      dhcpc_close(handle);
     }
-
-  /* Get an IP address.  Note that there is no logic for renewing the
-   * IP address in this example. The address should be renewed in
-   * (ds.lease_time / 2) seconds.
-   */
-
-  if (dhcpc_request(handle, &ds) == OK)
-    {
-      netlib_set_ipv4addr(NET_DEVNAME, &ds.ipaddr);
-
-      if (ds.netmask.s_addr != 0)
-        {
-          netlib_set_ipv4netmask(NET_DEVNAME, &ds.netmask);
-        }
-
-      if (ds.default_router.s_addr != 0)
-        {
-          netlib_set_dripv4addr(NET_DEVNAME, &ds.default_router);
-        }
-
-      if (ds.dnsaddr.s_addr != 0)
-        {
-          netlib_set_ipv4dnsaddr(&ds.dnsaddr);
-        }
-    }
-
-  dhcpc_close(handle);
 #endif
 
 #ifdef CONFIG_NETUTILS_NTPCLIENT
