@@ -42,9 +42,9 @@ struct usrsock_rpmsg_s
   pid_t                 pid;
   pthread_mutex_t       mutex;
   pthread_cond_t        cond;
-  struct socket         socks[CONFIG_NSOCKET_DESCRIPTORS];
-  struct rpmsg_endpoint *epts[CONFIG_NSOCKET_DESCRIPTORS];
-  struct pollfd         pfds[CONFIG_NSOCKET_DESCRIPTORS];
+  struct socket         socks[CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS];
+  struct rpmsg_endpoint *epts[CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS];
+  struct pollfd         pfds[CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS];
 };
 
 /****************************************************************************
@@ -204,16 +204,14 @@ static int usrsock_rpmsg_socket_handler(struct rpmsg_endpoint *ept,
   int retr;
   int ret = -ENFILE;
 
-  for (i = 0; i < CONFIG_NSOCKET_DESCRIPTORS; i++)
+  for (i = 0; i < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS; i++)
     {
       pthread_mutex_lock(&priv->mutex);
-      if (priv->socks[i].s_crefs == 0)
+      if (priv->socks[i].s_conn == NULL)
         {
-          priv->socks[i].s_crefs++;
-          pthread_mutex_unlock(&priv->mutex);
-
           ret = psock_socket(req->domain, req->type, req->protocol,
                              &priv->socks[i]);
+          pthread_mutex_unlock(&priv->mutex);
           if (ret >= 0)
             {
               psock_fcntl(&priv->socks[i], F_SETFL,
@@ -222,10 +220,6 @@ static int usrsock_rpmsg_socket_handler(struct rpmsg_endpoint *ept,
               priv->epts[i] = ept;
               ret = i; /* Return index as the usockid */
             }
-          else
-            {
-              priv->socks[i].s_crefs--;
-            }
 
           break;
         }
@@ -256,7 +250,8 @@ static int usrsock_rpmsg_close_handler(struct rpmsg_endpoint *ept,
   struct usrsock_rpmsg_s *priv = priv_;
   int ret = -EBADF;
 
-  if (req->usockid >= 0 && req->usockid < CONFIG_NSOCKET_DESCRIPTORS)
+  if (req->usockid >= 0 &&
+      req->usockid < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS)
     {
       priv->pfds[req->usockid].ptr = NULL;
       priv->epts[req->usockid] = NULL;
@@ -286,7 +281,8 @@ static int usrsock_rpmsg_connect_handler(struct rpmsg_endpoint *ept,
   int retr;
   int ret = -EBADF;
 
-  if (req->usockid >= 0 && req->usockid < CONFIG_NSOCKET_DESCRIPTORS)
+  if (req->usockid >= 0 &&
+      req->usockid < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS)
     {
       ret = psock_connect(&priv->socks[req->usockid],
               (const struct sockaddr *)(req + 1), req->addrlen);
@@ -329,7 +325,8 @@ static int usrsock_rpmsg_sendto_handler(struct rpmsg_endpoint *ept,
   ssize_t ret = -EBADF;
   int retr;
 
-  if (req->usockid >= 0 && req->usockid < CONFIG_NSOCKET_DESCRIPTORS)
+  if (req->usockid >= 0 &&
+      req->usockid < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS)
     {
       ret = psock_sendto(&priv->socks[req->usockid],
               (const void *)(req + 1) + req->addrlen, req->buflen,
@@ -377,7 +374,8 @@ static int usrsock_rpmsg_recvfrom_handler(struct rpmsg_endpoint *ept,
       buflen = len - sizeof(*ack) - inaddrlen;
     }
 
-  if (req->usockid >= 0 && req->usockid < CONFIG_NSOCKET_DESCRIPTORS)
+  if (req->usockid >= 0 &&
+      req->usockid < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS)
     {
       ret = psock_recvfrom(&priv->socks[req->usockid],
               (void *)(ack + 1) + inaddrlen, buflen, req->flags,
@@ -411,7 +409,8 @@ static int usrsock_rpmsg_setsockopt_handler(struct rpmsg_endpoint *ept,
   struct usrsock_rpmsg_s *priv = priv_;
   int ret = -EBADF;
 
-  if (req->usockid >= 0 && req->usockid < CONFIG_NSOCKET_DESCRIPTORS)
+  if (req->usockid >= 0 &&
+      req->usockid < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS)
     {
       ret = psock_setsockopt(&priv->socks[req->usockid],
               req->level, req->option, req + 1, req->valuelen);
@@ -432,7 +431,8 @@ static int usrsock_rpmsg_getsockopt_handler(struct rpmsg_endpoint *ept,
   uint32_t len;
 
   ack = rpmsg_get_tx_payload_buffer(ept, &len, true);
-  if (req->usockid >= 0 && req->usockid < CONFIG_NSOCKET_DESCRIPTORS)
+  if (req->usockid >= 0 &&
+      req->usockid < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS)
     {
       ret = psock_getsockopt(&priv->socks[req->usockid],
               req->level, req->option, ack + 1, &optlen);
@@ -455,7 +455,8 @@ static int usrsock_rpmsg_getsockname_handler(struct rpmsg_endpoint *ept,
   uint32_t len;
 
   ack = rpmsg_get_tx_payload_buffer(ept, &len, true);
-  if (req->usockid >= 0 && req->usockid < CONFIG_NSOCKET_DESCRIPTORS)
+  if (req->usockid >= 0 &&
+      req->usockid < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS)
     {
       ret = psock_getsockname(&priv->socks[req->usockid],
               (struct sockaddr *)(ack + 1), &outaddrlen);
@@ -478,7 +479,8 @@ static int usrsock_rpmsg_getpeername_handler(struct rpmsg_endpoint *ept,
   uint32_t len;
 
   ack = rpmsg_get_tx_payload_buffer(ept, &len, true);
-  if (req->usockid >= 0 && req->usockid < CONFIG_NSOCKET_DESCRIPTORS)
+  if (req->usockid >= 0 &&
+      req->usockid < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS)
     {
       ret = psock_getpeername(&priv->socks[req->usockid],
               (struct sockaddr *)(ack + 1), &outaddrlen);
@@ -496,7 +498,8 @@ static int usrsock_rpmsg_bind_handler(struct rpmsg_endpoint *ept,
   struct usrsock_rpmsg_s *priv = priv_;
   int ret = -EBADF;
 
-  if (req->usockid >= 0 && req->usockid < CONFIG_NSOCKET_DESCRIPTORS)
+  if (req->usockid >= 0 &&
+      req->usockid < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS)
     {
       ret = psock_bind(&priv->socks[req->usockid],
               (const struct sockaddr *)(req + 1), req->addrlen);
@@ -514,7 +517,8 @@ static int usrsock_rpmsg_listen_handler(struct rpmsg_endpoint *ept,
   int retr;
   int ret = -EBADF;
 
-  if (req->usockid >= 0 && req->usockid < CONFIG_NSOCKET_DESCRIPTORS)
+  if (req->usockid >= 0 &&
+      req->usockid < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS)
     {
       ret = psock_listen(&priv->socks[req->usockid], req->backlog);
     }
@@ -547,20 +551,19 @@ static int usrsock_rpmsg_accept_handler(struct rpmsg_endpoint *ept,
   int retr;
 
   ack = rpmsg_get_tx_payload_buffer(ept, &len, true);
-  if (req->usockid >= 0 && req->usockid < CONFIG_NSOCKET_DESCRIPTORS)
+  if (req->usockid >= 0 &&
+      req->usockid < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS)
     {
       ret = -ENFILE; /* Assume no free socket handler */
-      for (i = 0; i < CONFIG_NSOCKET_DESCRIPTORS; i++)
+      for (i = 0; i < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS; i++)
         {
           pthread_mutex_lock(&priv->mutex);
-          if (priv->socks[i].s_crefs == 0)
+          if (priv->socks[i].s_conn == NULL)
             {
-              priv->socks[i].s_crefs++;
-              pthread_mutex_unlock(&priv->mutex);
-
               ret = psock_accept(&priv->socks[req->usockid],
                       outaddrlen ? (struct sockaddr *)(ack + 1) : NULL,
                       outaddrlen ? &outaddrlen : NULL, &priv->socks[i]);
+              pthread_mutex_unlock(&priv->mutex);
               if (ret >= 0)
                 {
                   psock_fcntl(&priv->socks[i], F_SETFL,
@@ -581,10 +584,6 @@ static int usrsock_rpmsg_accept_handler(struct rpmsg_endpoint *ept,
 
                   ret = sizeof(int16_t); /* Return usockid size */
                 }
-              else
-                {
-                  priv->socks[i].s_crefs--;
-                }
 
               break;
             }
@@ -619,7 +618,8 @@ static int usrsock_rpmsg_ioctl_handler(struct rpmsg_endpoint *ept,
   uint32_t len;
 
   ack = rpmsg_get_tx_payload_buffer(ept, &len, true);
-  if (req->usockid >= 0 && req->usockid < CONFIG_NSOCKET_DESCRIPTORS)
+  if (req->usockid >= 0 &&
+      req->usockid < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS)
     {
       memcpy(ack + 1, req + 1, req->arglen);
       ret = psock_ioctl(&priv->socks[req->usockid],
@@ -688,7 +688,7 @@ static void usrsock_rpmsg_ns_bind(struct rpmsg_device *rdev, void *priv_,
 static void usrsock_rpmsg_ns_unbind(struct rpmsg_endpoint *ept)
 {
   struct usrsock_rpmsg_s *priv = ept->priv;
-  struct socket *socks[CONFIG_NSOCKET_DESCRIPTORS];
+  struct socket *socks[CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS];
   int count = 0;
   int i;
 
@@ -698,7 +698,7 @@ static void usrsock_rpmsg_ns_unbind(struct rpmsg_endpoint *ept)
 
   /* Collect all socks belong to the dead client */
 
-  for (i = 0; i < CONFIG_NSOCKET_DESCRIPTORS; i++)
+  for (i = 0; i < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS; i++)
     {
       if (priv->epts[i] == ept)
         {
@@ -751,7 +751,7 @@ static int usrsock_rpmsg_prepare_poll(struct usrsock_rpmsg_s *priv,
 
   pthread_cond_signal(&priv->cond);
 
-  for (i = 0; i < CONFIG_NSOCKET_DESCRIPTORS; i++)
+  for (i = 0; i < CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS; i++)
     {
       if (priv->pfds[i].ptr)
         {
@@ -823,7 +823,7 @@ static void usrsock_rpmsg_process_poll(struct usrsock_rpmsg_s *priv,
 
 int main(int argc, char *argv[])
 {
-  struct pollfd pfds[CONFIG_NSOCKET_DESCRIPTORS];
+  struct pollfd pfds[CONFIG_NETUTILS_USRSOCK_NSOCK_DESCRIPTORS];
   struct usrsock_rpmsg_s *priv;
   sigset_t sigmask;
   int ret;
@@ -839,6 +839,7 @@ int main(int argc, char *argv[])
   pthread_mutex_init(&priv->mutex, NULL);
   pthread_cond_init(&priv->cond, NULL);
 
+  signal(SIGUSR1, SIG_IGN);
   sigprocmask(SIG_SETMASK, NULL, &sigmask);
   sigaddset(&sigmask, SIGUSR1);
   sigprocmask(SIG_SETMASK, &sigmask, NULL);
