@@ -391,7 +391,9 @@ static int nsh_foreach_netdev(nsh_netdev_callback_t callback,
   dir = opendir(CONFIG_NSH_PROC_MOUNTPOINT "/net");
   if (dir == NULL)
     {
-      nsh_error(vtbl, g_fmtcmdfailed, cmd, "opendir", NSH_ERRNO);
+      nsh_error(vtbl,
+                "nsh: %s: Could not open %s/net (is procfs mounted?): %d\n",
+                cmd, CONFIG_NSH_PROC_MOUNTPOINT, NSH_ERRNO);
       return ERROR;
     }
 
