@@ -39,6 +39,7 @@
 
 #include <nuttx/config.h>
 
+#include <inttypes.h>
 #include <stdarg.h>
 #include <stdint.h>
 #include <stdbool.h>
@@ -167,7 +168,7 @@ struct cle_s
  ****************************************************************************/
 
 #if CONFIG_SYSTEM_CLE_DEBUGLEVEL > 0
-static int      cle_debug(FAR const char *fmt, ...);
+static void     cle_debug(FAR const char *fmt, ...);
 #endif
 
 /* Low-level display and data entry functions */
@@ -247,17 +248,15 @@ static const char g_setcolor[]     = VT100_FMT_FORE_COLOR;
  ****************************************************************************/
 
 #if CONFIG_SYSTEM_CLE_DEBUGLEVEL > 0
-static int cle_debug(FAR const char *fmt, ...)
+static void cle_debug(FAR const char *fmt, ...)
 {
   va_list ap;
-  int ret;
 
   /* Let vsyslog do the real work */
 
   va_start(ap, fmt);
-  ret = vsyslog(LOG_DEBUG, fmt, ap);
+  vsyslog(LOG_DEBUG, fmt, ap);
   va_end(ap);
-  return ret;
 }
 #endif
 
@@ -553,7 +552,7 @@ static int cle_getcursor(FAR struct cle_s *priv, FAR uint16_t *prow,
 
       /* ...we are done */
 
-      cleinfo("row=%ld column=%ld\n", row, column);
+      cleinfo("row=%" PRId32 " column=%" PRId32 "\n", row, column);
 
       /* Make sure that the values are within range */
 
@@ -758,7 +757,7 @@ static void cle_showtext(FAR struct cle_s *priv)
 
 static void cle_insertch(FAR struct cle_s *priv, char ch)
 {
-  cleinfo("curpos=%ld ch=%c[%02x]\n", priv->curpos,
+  cleinfo("curpos=%" PRId16 " ch=%c[%02x]\n", priv->curpos,
           isprint(ch) ? ch : '.', ch);
 
   /* Make space in the buffer for the new character */
@@ -1197,7 +1196,7 @@ int cle(FAR char *line, const char *prompt, uint16_t linelen,
       return -EINVAL;
     }
 
-  priv.coloffs = column - 1;
+  priv.coloffs = column;
 
   cleinfo("row=%d column=%d\n", priv.row, column);
 
