@@ -310,13 +310,14 @@ static int nxplayer_opendevice(FAR struct nxplayer_s *pplayer, int format,
 
       /* Device supports the format.  Open the device file. */
 
-      pplayer->dev_fd = open(pplayer->prefdevice, O_RDWR);
+      pplayer->dev_fd = open(pplayer->prefdevice, O_RDWR | O_CLOEXEC);
       if (pplayer->dev_fd == -1)
         {
           int errcode = errno;
           DEBUGASSERT(errcode > 0);
 
-          auderr("ERROR: Failed to open %s: %d\n", -errcode);
+          auderr("ERROR: Failed to open %s: %d\n",
+                 pplayer->prefdevice, -errcode);
           UNUSED(errcode);
           return -ENOENT;
         }
@@ -379,7 +380,7 @@ static int nxplayer_opendevice(FAR struct nxplayer_s *pplayer, int format,
           snprintf(path,  sizeof(path), "/dev/audio/%s", pdevice->d_name);
 #endif /* CONFIG_AUDIO_CUSTOM_DEV_PATH */
 
-          if ((pplayer->dev_fd = open(path, O_RDWR)) != -1)
+          if ((pplayer->dev_fd = open(path, O_RDWR | O_CLOEXEC)) != -1)
             {
               /* We have the device file open.  Now issue an AUDIO ioctls to
                * get the capabilities
@@ -790,12 +791,12 @@ static void *nxplayer_playthread(pthread_addr_t pvarg)
 
   audinfo("Entry\n");
 
-  /* Query the audio device for it's preferred buffer size / qty */
+  /* Query the audio device for its preferred buffer size / qty */
 
   if ((ret = ioctl(pplayer->dev_fd, AUDIOIOC_GETBUFFERINFO,
           (unsigned long) &buf_info)) != OK)
     {
-      /* Driver doesn't report it's buffer size.  Use our default. */
+      /* Driver doesn't report its buffer size.  Use our default. */
 
       buf_info.buffer_size = CONFIG_AUDIO_BUFFER_NUMBYTES;
       buf_info.nbuffers = CONFIG_AUDIO_NUM_BUFFERS;
@@ -1082,7 +1083,9 @@ static void *nxplayer_playthread(pthread_addr_t pvarg)
 
             /* Send a stop message to the device */
 
+#ifdef CONFIG_DEBUG_FEATURES
             audinfo("Stopping! outstanding=%d\n", outstanding);
+#endif
 
 #ifdef CONFIG_AUDIO_MULTI_SESSION
             ioctl(pplayer->dev_fd, AUDIOIOC_STOP,
@@ -1101,8 +1104,10 @@ static void *nxplayer_playthread(pthread_addr_t pvarg)
           /* Message indicating the playback is complete */
 
           case AUDIO_MSG_COMPLETE:
+#ifdef CONFIG_DEBUG_FEATURES
             audinfo("Play complete.  outstanding=%d\n", outstanding);
             DEBUGASSERT(outstanding == 0);
+#endif
             running = false;
             break;
 
@@ -1792,6 +1797,7 @@ static int nxplayer_playinternal(FAR struct nxplayer_s *pplayer,
   pthread_attr_t      tattr;
   FAR void           *value;
   struct audio_caps_desc_s cap_desc;
+  struct ap_buffer_info_s  buf_info;
 #ifdef CONFIG_NXPLAYER_INCLUDE_MEDIADIR
   char                path[128];
 #endif
@@ -1927,9 +1933,19 @@ static int nxplayer_playinternal(FAR struct nxplayer_s *pplayer,
       ioctl(pplayer->dev_fd, AUDIOIOC_CONFIGURE, (unsigned long)&cap_desc);
     }
 
+  /* Query the audio device for its preferred buffer count */
+
+  if (ioctl(pplayer->dev_fd, AUDIOIOC_GETBUFFERINFO,
+            (unsigned long)&buf_info) != OK)
+    {
+      /* Driver doesn't report its buffer size.  Use our default. */
+
+      buf_info.nbuffers = CONFIG_AUDIO_NUM_BUFFERS;
+    }
+
   /* Create a message queue for the playthread */
 
-  attr.mq_maxmsg  = 16;
+  attr.mq_maxmsg  = buf_info.nbuffers + 8;
   attr.mq_msgsize = sizeof(struct audio_msg_s);
   attr.mq_curmsgs = 0;
   attr.mq_flags   = 0;
@@ -1938,7 +1954,7 @@ static int nxplayer_playinternal(FAR struct nxplayer_s *pplayer,
            (unsigned long)((uintptr_t)pplayer));
 
   pplayer->mq = mq_open(pplayer->mqname, O_RDWR | O_CREAT, 0644, &attr);
-  if (pplayer->mq == NULL)
+  if (pplayer->mq == (mqd_t) -1)
     {
       /* Unable to open message queue! */
 
@@ -2132,7 +2148,7 @@ FAR struct nxplayer_s *nxplayer_create(void)
   pplayer->prefformat = 0;
   pplayer->preftype = 0;
 #endif
-  pplayer->mq = NULL;
+  pplayer->mq = 0;
   pplayer->play_id = 0;
   pplayer->crefs = 1;
 
@@ -2351,7 +2367,7 @@ int nxplayer_systemreset(FAR struct nxplayer_s *pplayer)
 #else
       snprintf(path,  sizeof(path), "/dev/audio/%s", pdevice->d_name);
 #endif
-      if ((pplayer->dev_fd = open(path, O_RDWR)) != -1)
+      if ((pplayer->dev_fd = open(path, O_RDWR | O_CLOEXEC)) != -1)
         {
           /* We have the device file open.  Now issue an
            * AUDIO ioctls to perform a HW reset
