@@ -88,13 +88,14 @@ static int nxrecorder_opendevice(FAR struct nxrecorder_s *precorder)
 
       /* Device supports the format.  Open the device file. */
 
-      precorder->dev_fd = open(precorder->device, O_RDWR);
+      precorder->dev_fd = open(precorder->device, O_RDWR | O_CLOEXEC);
       if (precorder->dev_fd == -1)
         {
           int errcode = errno;
           DEBUGASSERT(errcode > 0);
 
-          auderr("ERROR: Failed to open %s: %d\n", -errcode);
+          auderr("ERROR: Failed to open %s: %d\n",
+                 precorder->device, -errcode);
           UNUSED(errcode);
           return -ENOENT;
         }
@@ -241,12 +242,12 @@ static void *nxrecorder_recordthread(pthread_addr_t pvarg)
 
   audinfo("Entry\n");
 
-  /* Query the audio device for it's preferred buffer size / qty */
+  /* Query the audio device for its preferred buffer size / qty */
 
   if ((ret = ioctl(precorder->dev_fd, AUDIOIOC_GETBUFFERINFO,
           (unsigned long) &buf_info)) != OK)
     {
-      /* Driver doesn't report it's buffer size.  Use our default. */
+      /* Driver doesn't report its buffer size.  Use our default. */
 
       buf_info.buffer_size = CONFIG_AUDIO_BUFFER_NUMBYTES;
       buf_info.nbuffers = CONFIG_AUDIO_NUM_BUFFERS;
@@ -484,7 +485,9 @@ static void *nxrecorder_recordthread(pthread_addr_t pvarg)
 
             /* Send a stop message to the device */
 
+#ifdef CONFIG_DEBUG_FEATURES
             audinfo("Stopping! outstanding=%d\n", outstanding);
+#endif
 
 #ifdef CONFIG_AUDIO_MULTI_SESSION
             ioctl(precorder->dev_fd, AUDIOIOC_STOP,
@@ -503,7 +506,9 @@ static void *nxrecorder_recordthread(pthread_addr_t pvarg)
           /* Message indicating the recordback is complete */
 
           case AUDIO_MSG_COMPLETE:
+#ifdef CONFIG_DEBUG_FEATURES
             audinfo("Record complete.  outstanding=%d\n", outstanding);
+#endif
             running = false;
             break;
 
@@ -529,7 +534,7 @@ err_out:
           if (pbuffers[x] != NULL)
             {
 #ifdef CONFIG_AUDIO_MULTI_SESSION
-              buf_desc.session = pplayer->session;
+              buf_desc.session = precorder->session;
 #endif
               buf_desc.u.buffer = pbuffers[x];
               ioctl(precorder->dev_fd,
@@ -768,6 +773,7 @@ int nxrecorder_recordraw(FAR struct nxrecorder_s *precorder,
   struct sched_param       sparam;
   pthread_attr_t           tattr;
   struct audio_caps_desc_s cap_desc;
+  struct ap_buffer_info_s  buf_info;
   FAR void                 *value;
   int                      ret;
 
@@ -839,9 +845,19 @@ int nxrecorder_recordraw(FAR struct nxrecorder_s *precorder,
       goto err_out;
     }
 
+  /* Query the audio device for its preferred buffer count */
+
+  if (ioctl(precorder->dev_fd, AUDIOIOC_GETBUFFERINFO,
+            (unsigned long)&buf_info) != OK)
+    {
+      /* Driver doesn't report its buffer size.  Use our default. */
+
+      buf_info.nbuffers = CONFIG_AUDIO_NUM_BUFFERS;
+    }
+
   /* Create a message queue for the recordthread */
 
-  attr.mq_maxmsg  = 16;
+  attr.mq_maxmsg  = buf_info.nbuffers + 8;
   attr.mq_msgsize = sizeof(struct audio_msg_s);
   attr.mq_curmsgs = 0;
   attr.mq_flags   = 0;
@@ -850,7 +866,7 @@ int nxrecorder_recordraw(FAR struct nxrecorder_s *precorder,
            (unsigned long)((uintptr_t)precorder));
 
   precorder->mq = mq_open(precorder->mqname, O_RDWR | O_CREAT, 0644, &attr);
-  if (precorder->mq == NULL)
+  if (precorder->mq == (mqd_t) -1)
     {
       /* Unable to open message queue! */
 
@@ -952,7 +968,7 @@ FAR struct nxrecorder_s *nxrecorder_create(void)
   precorder->dev_fd = -1;
   precorder->fd = -1;
   precorder->device[0] = '\0';
-  precorder->mq = NULL;
+  precorder->mq = 0;
   precorder->record_id = 0;
   precorder->crefs = 1;
 
