@@ -1,5 +1,5 @@
 /****************************************************************************
- * testing/fstest/fstest_main.c
+ * apps/testing/fstest/fstest_main.c
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -39,6 +39,7 @@
 #include <errno.h>
 #include <crc32.h>
 #include <debug.h>
+#include <assert.h>
 
 /****************************************************************************
  * Pre-processor Definitions
@@ -90,6 +91,7 @@ struct fstest_filedesc_s
   bool failed;
   size_t len;
   uint32_t crc;
+  uint32_t hash;
 };
 
 /****************************************************************************
@@ -187,6 +189,29 @@ static inline char fstest_randchar(void)
     }
 }
 
+/****************************************************************************
+ * Name: fstest_checkexit
+ ****************************************************************************/
+
+static bool fstest_checkexit(FAR struct fstest_filedesc_s *file)
+{
+  int i;
+  bool ret = false;
+
+  for (i = 0; i < CONFIG_TESTING_FSTEST_MAXOPEN; i++)
+    {
+      if (!g_files[i].deleted &&
+          &g_files[i] != file &&
+          g_files[i].hash == file->hash)
+        {
+          ret = true;
+          break;
+        }
+    }
+
+  return ret;
+}
+
 /****************************************************************************
  * Name: fstest_randname
  ****************************************************************************/
@@ -200,8 +225,11 @@ static inline void fstest_randname(FAR struct fstest_filedesc_s *file)
   int i;
 
   dirlen   = strlen(g_mountdir);
-  maxname  = CONFIG_TESTING_FSTEST_MAXNAME - dirlen;
-  namelen  = (rand() % maxname) + 1;
+
+  /* Force the max filename lengh and also the min name len = 4 */
+
+  maxname  = CONFIG_TESTING_FSTEST_MAXNAME - dirlen - 3;
+  namelen  = (rand() % maxname) + 4;
   alloclen = namelen + dirlen;
 
   file->name = (FAR char *)malloc(alloclen + 1);
@@ -213,12 +241,19 @@ static inline void fstest_randname(FAR struct fstest_filedesc_s *file)
     }
 
   memcpy(file->name, g_mountdir, dirlen);
-  for (i = dirlen; i < alloclen; i++)
-    {
-      file->name[i] = fstest_randchar();
-    }
 
-  file->name[alloclen] = '\0';
+  do
+    {
+      for (i = dirlen; i < alloclen; i++)
+        {
+          file->name[i] = fstest_randchar();
+        }
+
+      file->name[alloclen] = '\0';
+      file->hash = crc32((const uint8_t *)file->name + dirlen,
+                         alloclen - dirlen);
+    }
+  while (fstest_checkexit(file));
 }
 
 /****************************************************************************
@@ -247,6 +282,7 @@ static void fstest_freefile(FAR struct fstest_filedesc_s *file)
   if (file->name)
     {
       free(file->name);
+      file->name = NULL;
     }
 
   memset(file, 0, sizeof(struct fstest_filedesc_s));
@@ -386,7 +422,7 @@ static inline int fstest_wrfile(FAR struct fstest_filedesc_s *file)
         {
           printf("ERROR: Failed to open file for writing: %d\n", errno);
           printf("  File name: %s\n", file->name);
-          printf("  File size: %d\n", file->len);
+          printf("  File size: %zd\n", file->len);
         }
 
       fstest_freefile(file);
@@ -427,7 +463,7 @@ static inline int fstest_wrfile(FAR struct fstest_filedesc_s *file)
             {
               printf("ERROR: Failed to write file: %d\n", errcode);
               printf("  File name:    %s\n", file->name);
-              printf("  File size:    %d\n", file->len);
+              printf("  File size:    %zd\n", file->len);
               printf("  Write offset: %ld\n", (long)offset);
               printf("  Write size:   %ld\n", (long)nbytestowrite);
             }
@@ -455,7 +491,7 @@ static inline int fstest_wrfile(FAR struct fstest_filedesc_s *file)
         {
           printf("ERROR: Partial write:\n");
           printf("  File name:    %s\n", file->name);
-          printf("  File size:    %d\n", file->len);
+          printf("  File size:    %zd\n", file->len);
           printf("  Write offset: %ld\n", (long)offset);
           printf("  Write size:   %ld\n", (long)nbytestowrite);
           printf("  Written:      %ld\n", (long)nbyteswritten);
@@ -541,7 +577,7 @@ static ssize_t fstest_rdblock(int fd, FAR struct fstest_filedesc_s *file,
             {
               printf("ERROR: Failed to read file: %d\n", errno);
               printf("  File name:    %s\n", file->name);
-              printf("  File size:    %d\n", file->len);
+              printf("  File size:    %zd\n", file->len);
               printf("  Read offset:  %ld\n", (long)offset);
               printf("  Read size:    %ld\n", (long)len);
               return ERROR;
@@ -552,7 +588,7 @@ static ssize_t fstest_rdblock(int fd, FAR struct fstest_filedesc_s *file,
 #if 0 /* No... we do this on purpose sometimes */
           printf("ERROR: Unexpected end-of-file:\n");
           printf("  File name:    %s\n", file->name);
-          printf("  File size:    %d\n", file->len);
+          printf("  File size:    %zd\n", file->len);
           printf("  Read offset:  %ld\n", (long)offset);
           printf("  Read size:    %ld\n", (long)len);
 #endif
@@ -562,7 +598,7 @@ static ssize_t fstest_rdblock(int fd, FAR struct fstest_filedesc_s *file,
         {
           printf("ERROR: Partial read:\n");
           printf("  File name:    %s\n", file->name);
-          printf("  File size:    %d\n", file->len);
+          printf("  File size:    %zd\n", file->len);
           printf("  Read offset:  %ld\n", (long)offset);
           printf("  Read size:    %ld\n", (long)len);
           printf("  Bytes read:   %ld\n", (long)nbytesread);
@@ -592,7 +628,7 @@ static inline int fstest_rdfile(FAR struct fstest_filedesc_s *file)
         {
           printf("ERROR: Failed to open file for reading: %d\n", errno);
           printf("  File name: %s\n", file->name);
-          printf("  File size: %d\n", file->len);
+          printf("  File size: %zd\n", file->len);
         }
 
       return ERROR;
@@ -620,9 +656,9 @@ static inline int fstest_rdfile(FAR struct fstest_filedesc_s *file)
   crc = crc32(g_fileimage, file->len);
   if (crc != file->crc)
     {
-      printf("ERROR: Bad CRC: %d vs %d\n", crc, file->crc);
+      printf("ERROR: Bad CRC: %" PRId32 " vs %" PRId32 "\n", crc, file->crc);
       printf("  File name: %s\n", file->name);
-      printf("  File size: %d\n", file->len);
+      printf("  File size: %zd\n", file->len);
       close(fd);
       return ERROR;
     }
@@ -634,7 +670,7 @@ static inline int fstest_rdfile(FAR struct fstest_filedesc_s *file)
     {
       printf("ERROR: Read past the end of file\n");
       printf("  File name:  %s\n", file->name);
-      printf("  File size:  %d\n", file->len);
+      printf("  File size:  %zd\n", file->len);
       printf("  Bytes read: %ld\n", (long)nbytesread);
       close(fd);
       return ERROR;
@@ -723,7 +759,7 @@ static int fstest_verifyfs(void)
                 {
                   printf("ERROR: Failed to read a file: %d\n", i);
                   printf("  File name: %s\n", file->name);
-                  printf("  File size: %d\n", file->len);
+                  printf("  File size: %zd\n", file->len);
                   return ERROR;
                 }
             }
@@ -734,7 +770,7 @@ static int fstest_verifyfs(void)
 #if CONFIG_TESTING_FSTEST_VERBOSE != 0
                   printf("ERROR: Successfully read a deleted file\n");
                   printf("  File name: %s\n", file->name);
-                  printf("  File size: %d\n", file->len);
+                  printf("  File size: %zd\n", file->len);
 #endif
                   fstest_freefile(file);
                   g_ndeleted--;
@@ -807,7 +843,7 @@ static int fstest_delfiles(void)
                 {
                   printf("ERROR: Unlink %d failed: %d\n", i + 1, errno);
                   printf("  File name:  %s\n", file->name);
-                  printf("  File size:  %d\n", file->len);
+                  printf("  File size:  %zd\n", file->len);
                   printf("  File index: %d\n", j);
 
                   /* If we don't do this we can get stuck in an infinite
@@ -859,7 +895,7 @@ static int fstest_delallfiles(void)
             {
                printf("ERROR: Unlink %d failed: %d\n", i + 1, errno);
                printf("  File name:  %s\n", file->name);
-               printf("  File size:  %d\n", file->len);
+               printf("  File size:  %zd\n", file->len);
                printf("  File index: %d\n", i);
             }
           else
