@@ -57,6 +57,7 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
+#include <inttypes.h>
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -279,6 +280,18 @@ int wpa_driver_wext_associate(FAR struct wpa_wconfig_s *wconfig)
       goto close_socket;
     }
 
+  if (wconfig->freq)
+    {
+      ret = wapi_set_freq(sockfd, wconfig->ifname,
+                          wconfig->freq,
+                          wconfig->flag == WAPI_FREQ_FIXED ?
+                          IW_FREQ_FIXED : IW_FREQ_AUTO);
+      if (ret < 0)
+        {
+          nerr("WARNING: Fail set freq: %d\n", ret);
+        }
+    }
+
   if (wconfig->phraselen > 0)
     {
       ret = wpa_driver_wext_set_key_ext(sockfd, wconfig->ifname,
@@ -292,20 +305,24 @@ int wpa_driver_wext_associate(FAR struct wpa_wconfig_s *wconfig)
         }
     }
 
-  if (wconfig->bssid)
+  if (wconfig->ssid)
+    {
+      ret = wapi_set_essid(sockfd, wconfig->ifname,
+                           wconfig->ssid, WAPI_ESSID_ON);
+      if (ret < 0)
+        {
+          nerr("ERROR: Fail set ssid: %d\n", ret);
+          goto close_socket;
+        }
+    }
+  else if (wconfig->bssid)
     {
       ret = wapi_set_ap(sockfd, wconfig->ifname,
                         (FAR const struct ether_addr *)wconfig->bssid);
-    }
-  else
-    {
-      ret = wapi_set_essid(sockfd, wconfig->ifname, wconfig->ssid,
-                           WAPI_ESSID_ON);
-    }
-
-  if (ret < 0)
-    {
-      nerr("ERROR: Fail set ssid: %d\n", ret);
+      if (ret < 0)
+        {
+          nerr("ERROR: Fail set bssid: %d\n", ret);
+        }
     }
 
 close_socket:
@@ -347,8 +364,9 @@ static int wpa_driver_wext_process_auth_param(int sockfd,
       errcode = errno;
       if (errcode != EOPNOTSUPP)
         {
-          nerr("ERROR: SIOCSIWAUTH(param %d value 0x%x) failed: %d)",
-               idx, value, errcode);
+          nerr("ERROR: SIOCSIWAUTH(param %d value 0x%" PRIx32
+               ") failed: %d)",
+               idx, *value, errcode);
         }
 
       ret = errcode == EOPNOTSUPP ? -2 : -1;
